Views reference — django-authopenid v1.0 documentation

### Navigation

- index
- next |
- previous |
- django-authopenid v1.0 documentation »

# Views reference

`django_authopenid.views.` `signin_success`(request, identity_url, openid_response, redirect_field_name='next', **kwargs)

  openid signin success.

  If the openid is already registered, the user is redirected to url set par next or in settings with OPENID_REDIRECT_NEXT variable. If none of these urls are set user is redirectd to /.

  if openid isn’t registered user is redirected to register page.

`django_authopenid.views.` `signin_failure`(request, message, template_name='authopenid/signin.html', redirect_field_name='next', openid_form=<class 'django_authopenid.forms.OpenidSigninForm'>, auth_form=<class 'django.contrib.auth.forms.AuthenticationForm'>, extra_context=None, **kwargs)

  falure with openid signin. Go back to signin page.

  Attr request: | request object
  Attr template_name:
  | string, name of template to use, default is ‘authopenid/signin.html’
  Attr redirect_field_name:
  | string, field name used for redirect. by default ‘next’
  Attr openid_form:
  | form use for openid signin, by default OpenidSigninForm
  Attr auth_form: | form object used for legacy authentification.

  by default AuthentificationForm form auser auth contrib. :attr extra_context: A dictionary of variables to add to the template context. Any callable object in this dictionary will be called to produce the end result which appears in the context.

`django_authopenid.views.` `complete_signin`(request, redirect_field_name='next', openid_form=<class 'django_authopenid.forms.OpenidSigninForm'>, auth_form=<class 'django.contrib.auth.forms.AuthenticationForm'>, on_success=<function signin_success at 0x214a5f0>, on_failure=<function signin_failure at 0x214a630>, extra_context=None)

  in case of complete signin with openid

  Attr request: | request object
  Attr openid_form:
  | form use for openid signin, by default OpenidSigninForm
  Attr auth_form: | form object used for legacy authentification.

  by default AuthentificationForm form auser auth contrib. :attr on_success: callbale, function used when openid auth success :attr on_failure: callable, function used when openid auth failed. :attr extra_context: A dictionary of variables to add to the template context. Any callable object in this dictionary will be called to produce the end result which appears in the context.

`django_authopenid.views.` `signin`(request, *args, **kwargs)

`django_authopenid.views.` `register`(request, *args, **kwargs)

`django_authopenid.views.` `signout`()
  signout from the website. Remove openid from session and kill it.

`django_authopenid.views.` `password_change`()

  View that allow a user to add a password to its account or change it.

  Attr request: | request object
  Attr template_name:
  | string, name of template to use, ‘authopenid/password_change_form.html’ by default
  Attr set_password_form:
  | form use to create a new password. By default `django.contrib.auth.forms.SetPasswordForm`
  Attr change_password_form:
  | form objectto change passworf.

  by default django.contrib.auth.forms.SetPasswordForm.PasswordChangeForm form auser auth contrib. :attr post_change_redirect: url used to redirect user after password change. It take the register_form as param. :attr extra_context: A dictionary of variables to add to the template context. Any callable object in this dictionary will be called to produce the end result which appears in the context.

`django_authopenid.views.` `associate`()

  View that allow a user to associate a new openid to its account.

  Attr request: | request object
  Attr template_name:
  | string, name of template to use, ‘authopenid/associate.html’ by default
  Attr openid_form:
  | form use enter openid url. By default `django_authopenid.forms.AssociateOpenID`
  Attr redirect_field_name:
  | string, field name used for redirect. by default ‘next’
  Attr on_success:
  | callbale, function used when openid auth success
  Attr on_failure:
  | callable, function used when openid auth failed. by default ``django_authopenid.views.associate_failure`
  Attr extra_context:
  | A dictionary of variables to add to the template context. A callable object in this dictionary will be called to produce the end result which appears in the context.

`django_authopenid.views.` `associate_success`()
  function used when new openid association success. redirect the user

`django_authopenid.views.` `associate_failure`()
  function used when new openid association fail

`django_authopenid.views.` `complete_associate`()
  in case of complete association with openid

`django_authopenid.views.` `dissociate`()
  view used to dissociate an openid from an account

`django_authopenid.views.` `xrdf`(request, template_name='authopenid/yadis.xrdf')
  view used to process the xrdf file

See also

django-registration views documentation .

### Navigation

- index
- next |
- previous |
- django-authopenid v1.0 documentation »